@@ -33,11 +33,7 @@
 #pod         my ( $self ) = @_;
 #pod         my $expected = $self->expected;
 #pod         $self->build();
-#pod         if ( exists( $expected->{ exception } ) ) {
-#pod             cmp_deeply( $self->exception, $expected->{ exception } );
-#pod         } else {
-#pod             is( $self->exception, undef );
-#pod         };
+#pod         cmp_deeply( $self->exception, $expected->{ exception } );
 #pod         if ( exists( $expected->{ messages } ) ) {
 #pod             cmp_deeply( $self->messages, $expected->{ messages } );
 #pod         };
@@ -67,7 +63,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.4.3'; # VERSION
+our $VERSION = 'v0.4.3_01'; # TRIAL VERSION
 
 use Dist::Zilla::Tester::DieHard v0.5.0;    # Need `release` method.
 use File::Temp qw{ tempdir };
@@ -83,6 +79,46 @@ use Try::Tiny;
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =var $Cleanup
+#pod
+#pod C<Dist::Zilla::Tester> creates distribution source and build directories in a temporary directory,
+#pod and then unconditionally cleans it up. Sometimes (especially in case of test failure) such behavior
+#pod may be not desirable — you may want to look at source or built files for troubleshooting purposes.
+#pod
+#pod C<Test::Dist::Zilla> provides control over temporary directory via C<$Test::Dist::Zilla::Cleanup>
+#pod package variable:
+#pod
+#pod =over
+#pod
+#pod =item C<0>
+#pod
+#pod Never clean up temporary directory.
+#pod
+#pod =item C<1>
+#pod
+#pod Clean up temporary directory only if the test is passed.
+#pod
+#pod =item C<2>
+#pod
+#pod Always clean up temporary directory.
+#pod
+#pod =back
+#pod
+#pod Default value is C<1>.
+#pod
+#pod If temporary directory is going to remain, the test output will contain diagnostic message like
+#pod this one:
+#pod
+#pod     # tempdir: tmp/AKrvBhhM4M
+#pod
+#pod to help you identify the temporary directory created for the test.
+#pod
+#pod =cut
+
+our $Cleanup = 1;                       ## no critic ( ProhibitPackageVars )
+
+# --------------------------------------------------------------------------------------------------
+
 #pod =attr C<dist>
 #pod
 #pod Hash of distribution options: C<name>, C<version> C<abstract>, etc. to write to the test's
@@ -230,15 +266,17 @@ sub _build_files {
 #pod appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
 #pod constructing fails, so C<< $self->tzil->log_message >> returns the log messages anyway.
 #pod
-#pod Note: Avoid calling C<build> on C<tzil>:
+#pod Note: Avoid calling C<build> and C<release> on C<tzil>:
 #pod
-#pod     $self->tzil->build();
+#pod     $self->tzil->build();       # NOT recommended
+#pod     $self->tzil->release();     # NOT recommended
 #pod
-#pod Call C<build> directly on C<$self> instead:
+#pod Call C<build> and C<release> directly on C<$self> instead:
 #pod
-#pod     $self->build();
+#pod     $self->build();             # recommended
+#pod     $self->release();           # recommended
 #pod
-#pod See C<build> method description for difference.
+#pod See C<build> and C<release> method descriptions for difference.
 #pod
 #pod Examples:
 #pod
@@ -345,7 +383,7 @@ around [ qw{ build release } ] => sub {
 
 #pod =attr C<exception>
 #pod
-#pod Exception occurred during build, or C<undef> is no exception was occurred.
+#pod Exception occurred, or C<undef> is no exception was occurred.
 #pod
 #pod     test 'Post-build' => sub {
 #pod         my ( $self ) = @_;
@@ -499,12 +537,25 @@ has _annotation => (
 
 after run_test => sub {
     my ( $self ) = @_;
+    require Test::Builder;
     my $tb = Test::Builder->new();
     if ( not $tb->is_passing and $self->_annotation ne '' ) {
         ( my $annotation = $self->_annotation ) =~ s{^}{| }gmx;
         $tb->diag( $annotation );
         $self->{ _annotation } = '';
     };
+    # Manage temporary directory:
+    if ( my $tempdir = $self->tzil->tempdir_obj ) {
+        # `tzil` could be `Survivor` which does not have temp dir (`tempdir_obj` returns `undef`).
+        my $cleanup = $Cleanup;
+        if ( $cleanup == 1 ) {
+            $cleanup = $tb->is_passing;
+        };
+        if ( not $cleanup ) {
+            diag( "tempdir: $tempdir" );
+            $tempdir->unlink_on_destroy( $cleanup );
+        };
+    };
 };
 
 # --------------------------------------------------------------------------------------------------
@@ -544,6 +595,8 @@ sub _anno_text {
 #pod
 #pod =for :list
 #pod = L<Test::Dist::Zilla::Build>
+#pod = L<Test::Dist::Zilla::BuiltFiles>
+#pod = L<Test::Dist::Zilla::Release>
 #pod = L<Test::Routine>
 #pod = L<Dist::Zilla>
 #pod = L<Dist::Zilla::Tester::DieHard>
@@ -576,7 +629,8 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.4.3, released on 2016-11-26 19:05 UTC.
+Version v0.4.3_01, released on 2016-12-19 22:05 UTC.
+This is a B<trial release>.
 
 =head1 SYNOPSIS
 
@@ -592,11 +646,7 @@ Version v0.4.3, released on 2016-11-26 19:05 UTC.
         my ( $self ) = @_;
         my $expected = $self->expected;
         $self->build();
-        if ( exists( $expected->{ exception } ) ) {
-            cmp_deeply( $self->exception, $expected->{ exception } );
-        } else {
-            is( $self->exception, undef );
-        };
+        cmp_deeply( $self->exception, $expected->{ exception } );
         if ( exists( $expected->{ messages } ) ) {
             cmp_deeply( $self->messages, $expected->{ messages } );
         };
@@ -711,15 +761,17 @@ By default C<Dist::Zilla> instance is created by calling C<< Builder->from_confi
 appropriate arguments. Thanks to C<Dist::Zilla::Tester::DieHard>, it is never dies even if
 constructing fails, so C<< $self->tzil->log_message >> returns the log messages anyway.
 
-Note: Avoid calling C<build> on C<tzil>:
+Note: Avoid calling C<build> and C<release> on C<tzil>:
 
-    $self->tzil->build();
+    $self->tzil->build();       # NOT recommended
+    $self->tzil->release();     # NOT recommended
 
-Call C<build> directly on C<$self> instead:
+Call C<build> and C<release> directly on C<$self> instead:
 
-    $self->build();
+    $self->build();             # recommended
+    $self->release();           # recommended
 
-See C<build> method description for difference.
+See C<build> and C<release> method descriptions for difference.
 
 Examples:
 
@@ -734,7 +786,7 @@ Examples:
 
 =head2 C<exception>
 
-Exception occurred during build, or C<undef> is no exception was occurred.
+Exception occurred, or C<undef> is no exception was occurred.
 
     test 'Post-build' => sub {
         my ( $self ) = @_;
@@ -844,12 +896,52 @@ you can write just
 
     $self->skip_if_exception;
 
+=head1 VARIABLES
+
+=head2 $Cleanup
+
+C<Dist::Zilla::Tester> creates distribution source and build directories in a temporary directory,
+and then unconditionally cleans it up. Sometimes (especially in case of test failure) such behavior
+may be not desirable — you may want to look at source or built files for troubleshooting purposes.
+
+C<Test::Dist::Zilla> provides control over temporary directory via C<$Test::Dist::Zilla::Cleanup>
+package variable:
+
+=over
+
+=item C<0>
+
+Never clean up temporary directory.
+
+=item C<1>
+
+Clean up temporary directory only if the test is passed.
+
+=item C<2>
+
+Always clean up temporary directory.
+
+=back
+
+Default value is C<1>.
+
+If temporary directory is going to remain, the test output will contain diagnostic message like
+this one:
+
+    # tempdir: tmp/AKrvBhhM4M
+
+to help you identify the temporary directory created for the test.
+
 =head1 SEE ALSO
 
 =over 4
 
 =item L<Test::Dist::Zilla::Build>
 
+=item L<Test::Dist::Zilla::BuiltFiles>
+
+=item L<Test::Dist::Zilla::Release>
+
 =item L<Test::Routine>
 
 =item L<Dist::Zilla>
