@@ -36,7 +36,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Check files built by your Dist::Zilla plugin
-our $VERSION = 'v0.4.3'; # VERSION
+our $VERSION = 'v0.4.3_01'; # TRIAL VERSION
 
 use Test::Routine;
 
@@ -89,7 +89,6 @@ test 'BuiltFiles' => sub {
     $self->skip_if_exception();
     my @names = keys( %{ $expected->{ files } } );          # Name of files to check.
     my $built_in = path( $self->tzil->built_in );           # Build directory.
-    plan 'no_plan';
     for my $name ( @names ) {
         my $exp  = $expected->{ files }->{ $name };         # Expected content.
         my $file = $built_in->child( $name );               # Actual file.
@@ -198,7 +197,8 @@ Test::Dist::Zilla::BuiltFiles - Check files built by your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.4.3, released on 2016-11-26 19:05 UTC.
+Version v0.4.3_01, released on 2016-12-19 22:05 UTC.
+This is a B<trial release>.
 
 =head1 SYNOPSIS
 
